@@ -537,6 +537,41 @@ class Map:
     def _init_(self):
         pass
 
+    def search(self, **kwargs):
+        """
+        네이버 지도 검색
+        """
+        url = "https://map.naver.com/v5/api/search?"
+        params = {
+            "type": "all",
+            "lang": "ko",
+        }
+        kwargs.update(params)
+        for k, v in kwargs.items():
+            url += f"{k}={v}&"
+        res = requests.get(url)
+        if res.status_code == 200:
+            return pd.DataFrame(res.json()['result']['place']['list'])
+        else:
+            return res
+
+    def sites_summary(self, site_id):
+        """
+        네이버 지도 장소 요약
+        """
+        url = f"https://map.naver.com/v5/api/sites/summary/{site_id}?"
+        params = {
+            "lang": "ko",
+        }
+        for k, v in params.items():
+            url += f"{k}={v}&"
+        res = requests.get(url)
+        if res.status_code == 200:
+            return res.json()
+        else:
+            return res
+
+
     def transit_directions_point_to_point(self, **kwargs):
         """
         네이버 지도 길찾기 대중교통 API
